#
# Cookbook Name:: nagios3
# Recipe:: nagios_client
#
# Copyright 2015, DennyZhang.com
#
# Apache License, Version 2.0
#

node.from_file(run_context.resolve_attribute('nagios3', 'default'))

case node['platform_family']
when 'debian'
  %w(nagios-nrpe-server nagios-plugins nagios-plugins-basic libsys-statistics-linux-perl).each do |x|
    apt_package x do
      action :install
    end
  end
when 'fedora', 'rhel', 'suse'
  %w(nagios-plugins-nrpe nagios-plugins-all nrpe perl-Sys-Statistics-Linux).each do |x|
    yum_package x do
      action :install
    end
  end
else
  Chef::Application.fatal!("Need to customize for OS of #{node['platform_family']}")
end

# Make sure nagios user to run admin commands like lsof without problem
file '/etc/sudoers.d/nagios' do
  mode '0440'
  content '%nagios ALL=(ALL:ALL) NOPASSWD: ALL'
end

###################### Install Basic Files for Checks #####################
remote_directory '/etc/nagios/log_cfg' do
  files_mode '0755'
  files_owner 'root'
  mode '0755'
  owner 'root'
  source 'log_cfg'
end
###########################################################################

######################## nagios check plugins ##########################
directory '/etc/nagios/nrpe.d' do
  owner 'root'
  group 'root'
  mode 0755
  recursive true
  action :create
end

allowed_hosts = node['nagios']['allowed_hosts'] + ',' + node['nagios']['server_ip']
template '/etc/nagios/nrpe.cfg' do
  source 'nrpe.cfg.erb'
  owner 'root'
  group 'root'
  mode 0755
  variables(
    :allowed_hosts => allowed_hosts
  )
  notifies :restart, "service[#{node['nagios']['nrpe_name']}]", :delayed
end

template '/etc/nagios/nrpe.d/common_nrpe.cfg' do
  source 'common_nrpe.cfg.erb'
  owner 'root'
  group 'root'
  mode 0755
  variables(
    :nagios_plugins => node['nagios']['plugins_dir']
  )
  notifies :restart, "service[#{node['nagios']['nrpe_name']}]", :delayed
end

template '/etc/nagios/nrpe.d/my_nrpe.cfg' do
  source 'my_nrpe.cfg.erb'
  owner 'root'
  group 'root'
  mode 0755
  variables(
    :apache_pid_file => node['nagios']['apache_pid_file'],
    :tomcat_cmd_pattern => 'tomcat7.*java.*MaxPermSize',
    :nagios_plugins => node['nagios']['plugins_dir']
  )
  notifies :restart, "service[#{node['nagios']['nrpe_name']}]", :delayed
end

template '/etc/nagios/nrpe.d/check_logfile.cfg' do
  source 'check_logfile.cfg.erb'
  owner 'root'
  group 'root'
  mode 0755
  variables(
    :nagios_plugins => node['nagios']['plugins_dir']
  )
  notifies :restart, "service[#{node['nagios']['nrpe_name']}]", :delayed
end

template '/etc/nagios/nrpe.d/check_port.cfg' do
  source 'check_port.cfg.erb'
  owner 'root'
  group 'root'
  mode 0755
  variables(
    :nagios_plugins => node['nagios']['plugins_dir']
  )
  notifies :restart, "service[#{node['nagios']['nrpe_name']}]", :delayed
end

directory node['nagios']['plugins_dir'] do
  owner 'root'
  group 'root'
  mode 0755
  recursive true
  action :create
end

%w(check_proc_mem check_proc_cpu check_proc_fd).each do |proc_nagios_plugin|
  remote_file "#{node['nagios']['plugins_dir']}/#{proc_nagios_plugin}.sh" do
    source "https://raw.githubusercontent.com/DennyZhang/#{proc_nagios_plugin}/master/#{proc_nagios_plugin}.sh"
    owner 'nagios'
    group 'nagios'
    mode '0755'
  end
end

%w(check_linux_stats.pl check_ip_address.sh).each do |x|
  template "#{node['nagios']['plugins_dir']}/#{x}" do
    source "#{x}.erb"
    owner 'root'
    group 'root'
    mode 0755
  end
end

# ######################### selenium_test ################################
# remote_file '/opt/selenium-server-standalone-2.38.0.jar' do
# source 'https://selenium.googlecode.com/files/selenium-server-standalone-2.38.0.jar'
# use_last_modified true
# mode '0755'
# action :create_if_missing
# end

########################################################################
# Install plugin
%w(check_logfiles check_service_status.sh).each do |x|
  cookbook_file "#{node['nagios']['plugins_dir']}/#{x}" do
    source x
    mode '0755'
  end
end

service node['nagios']['nrpe_name'] do
  supports :status => true, :restart => true, :reload => true
  action [:enable, :start]
end
